package org.greenstone.gatherer.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import org.greenstone.gatherer.Configuration;
import org.greenstone.gatherer.Dictionary;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.gui.SmarterTextArea;
import org.greenstone.gatherer.util.Utility;

/** Warn a user that they are about to add folder level metadata. */
public class WarningDialog
	 extends JDialog 
	 implements ActionListener {

	 static final private Dimension SIZE = new Dimension(400,160);

	 private int result = JOptionPane.CANCEL_OPTION;
	 private JButton cancel_button;
	 private JButton ok_button;
	 private JCheckBox show_check;
	 private String full_property;
	 private String warning_name;

	 public WarningDialog(String full_property, boolean can_cancel) {
		  super(Gatherer.g_man, "Warning", true);
		  // Determine the name of this prompt.
		  this.full_property = full_property;
		  warning_name = full_property.substring(full_property.indexOf(".") + 1);
		  // Now build dialog.
		  setSize(SIZE);
		  setTitle(get("Title"));
		  // Creation
		  JPanel content_pane = (JPanel) getContentPane();
		  JPanel text_pane = new JPanel();
		  JLabel icon_label = new JLabel(Utility.getImage("gatherer_medium.gif"));
		  SmarterTextArea text_area = new SmarterTextArea(get("Message"), false);
		  text_area.setCaretPosition(0);
		  text_area.setLineWrap(true);
		  text_area.setWrapStyleWord(true);
		  JPanel bottom_pane = new JPanel();
		  show_check = new JCheckBox(get("WarningDialog.Dont_Show_Again"), false);
		  JPanel control_pane = new JPanel();
		  ok_button = new JButton(get("General.OK"));
		  cancel_button = new JButton(get("General.Cancel"));
		  // Connection
		  ok_button.addActionListener(this);
		  cancel_button.addActionListener(this);
		  // Layout
		  icon_label.setBorder(BorderFactory.createEmptyBorder(0,0,0,5));

		  text_pane.setLayout(new BorderLayout());
		  text_pane.add(icon_label, BorderLayout.WEST);
		  text_pane.add(new JScrollPane(text_area), BorderLayout.CENTER);
		  
		  if(can_cancel) {
				control_pane.setLayout(new GridLayout(1,2,5,0));
				control_pane.add(ok_button);
				control_pane.add(cancel_button);
		  }
		  else {
				control_pane.setLayout(new BorderLayout());
				control_pane.add(ok_button, BorderLayout.EAST);
		  }

		  bottom_pane.setBorder(BorderFactory.createEmptyBorder(5,0,0,0));
		  bottom_pane.setLayout(new BorderLayout());
		  bottom_pane.add(show_check, BorderLayout.CENTER);
		  bottom_pane.add(control_pane, BorderLayout.EAST);

		  content_pane.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
		  content_pane.setLayout(new BorderLayout());
		  content_pane.add(text_pane, BorderLayout.CENTER);
		  content_pane.add(bottom_pane, BorderLayout.SOUTH);
		  // Position
		  if(Gatherer.g_man != null) {
				Rectangle frame_bounds = Gatherer.g_man.getBounds();
				setLocation(frame_bounds.x + (frame_bounds.width - SIZE.width) / 2, frame_bounds.y + (frame_bounds.height - SIZE.height) / 2);
		  }
		  else {
				Dimension screen_size = Toolkit.getDefaultToolkit().getScreenSize();
				setLocation((screen_size.width - SIZE.width) / 2, (screen_size.height - SIZE.height) / 2);
		  }
	 }

	 public void actionPerformed(ActionEvent event) {
		  if(event.getSource() == ok_button) {
				result = JOptionPane.OK_OPTION;
		  }
		  // Store the state of the show message checkbox.
		  Gatherer.config.set(full_property, true, !show_check.isSelected());
		  // Done.
		  dispose();
	 }

	 public int display() {
		  ///ystem.err.println("Show " + full_property + ": " + Gatherer.config.get(full_property, false));
		  if(Gatherer.config.get(full_property, false)) {
				// We only show if the warning has not been disabled.
				show();
		  }
		  // We are no longer showing this dialog, so result must always be true.
		  else {
				result = JOptionPane.OK_OPTION;
		  }
		  return result;
	 }

	 private String get(String key) {
		  if(key.indexOf(".") == -1) {
				key = warning_name + "." + key;
		  }
		  return Gatherer.dictionary.get(key);
	 }
}
